@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtLocation module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -53,7 +45,6 @@
 #include "qgeocameradata_p.h"
 #include "qgeocameracapabilities_p.h"
 #include "qgeomapcontroller_p.h"
-#include "mapnode_p.h"
 #include <cmath>
 
 #include <QtPositioning/QGeoCoordinate>
@@ -68,6 +59,7 @@
 #include <QtQml/qqmlinfo.h>
 #include <QModelIndex>
 #include <QtQuick/QQuickWindow>
+#include <QtQuick/QSGSimpleRectNode>
 #include <QtGui/QGuiApplication>
 #include <QCoreApplication>
 
@@ -191,7 +183,6 @@ QDeclarativeGeoMap::QDeclarativeGeoMap(QQuickItem *parent)
         activeMapType_(0),
         componentCompleted_(false),
         mappingManagerInitialized_(false),
-        window_(0),
         touchTimer_(-1),
         map_(0)
 {
@@ -365,16 +356,6 @@ QDeclarativeGeoMapGestureArea *QDeclarativeGeoMap::gesture()
     return gestureArea_;
 }
 
-/*!
-    \internal
-*/
-void QDeclarativeGeoMap::itemChange(ItemChange change, const ItemChangeData & data)
-{
-    QLOC_TRACE0;
-    if (change == ItemSceneChange)
-        window_ = data.window;
-}
-
 /*!
     \internal
 */
@@ -407,29 +388,27 @@ void QDeclarativeGeoMap::setupMapView(QDeclarativeGeoMapItemView *view)
 }
 
 /*!
-    \internal
-*/
-QSGNode *QDeclarativeGeoMap::updatePaintNode(QSGNode *oldNode, UpdatePaintNodeData *data)
+ * \internal
+ */
+QSGNode *QDeclarativeGeoMap::updatePaintNode(QSGNode *oldNode, UpdatePaintNodeData *)
 {
-    Q_UNUSED(data)
-    if (width() <= 0 || height() <= 0) {
+    if (!map_) {
         delete oldNode;
         return 0;
     }
 
-    MapNode *node = static_cast<MapNode *>(oldNode);
+    QSGSimpleRectNode *root = static_cast<QSGSimpleRectNode *>(oldNode);
+    if (!root)
+        root = new QSGSimpleRectNode(boundingRect(), QColor::fromRgbF(0.9, 0.9, 0.9));
+    else
+        root->setRect(boundingRect());
 
-    if (!node) {
-        node = new MapNode(map_);
-    }
+    QSGNode *content = root->childCount() ? root->firstChild() : 0;
+    content = map_->updateSceneGraph(content, window());
+    if (content && root->childCount() == 0)
+        root->appendChildNode(content);
 
-    if (!mappingManagerInitialized_)
-        return 0;
-
-    node->setSize(QSize(width(), height()));
-    node->update();
-
-    return node;
+    return root;
 }
 
 
@@ -1086,44 +1065,32 @@ void QDeclarativeGeoMap::fitViewportToMapItemsRefine(bool refine)
     double topLeftY = 0;
     double bottomRightX = 0;
     double bottomRightY = 0;
+    bool haveQuickItem = false;
 
     // find bounds of all map items
-    QGeoCoordinate geoCenter;
-    QDoubleVector2D centerPt;
     int itemCount = 0;
     for (int i = 0; i < mapItems_.count(); ++i) {
         if (!mapItems_.at(i))
             continue;
         QDeclarativeGeoMapItemBase *item = mapItems_.at(i).data();
+        if (!item)
+            continue;
 
         // skip quick items in the first pass and refine the fit later
         if (refine) {
             QDeclarativeGeoMapQuickItem *quickItem =
                     qobject_cast<QDeclarativeGeoMapQuickItem*>(item);
-            if (quickItem)
-                    continue;
+            if (quickItem) {
+                haveQuickItem = true;
+                continue;
+            }
         }
 
-        // account for the special case - circle
-        QDeclarativeCircleMapItem *circleItem =
-                qobject_cast<QDeclarativeCircleMapItem *>(item);
+        topLeftX = item->position().x();
+        topLeftY = item->position().y();
+        bottomRightX = topLeftX + item->width();
+        bottomRightY = topLeftY + item->height();
 
-        if ((!circleItem || !circleItem->center().isValid()) && !item)
-            continue;
-        if (circleItem) {
-            geoCenter = circleItem->center();
-            centerPt = map_->coordinateToScreenPosition(geoCenter, false);
-            topLeftX = centerPt.x() - circleItem->width() / 2.0;
-            topLeftY = centerPt.y() - circleItem->height() / 2.0;
-            bottomRightX = centerPt.x() + circleItem->width() / 2.0;
-            bottomRightY = centerPt.y() + circleItem->height() / 2.0;
-        } else if (item) {
-            topLeftX = item->position().x();
-            topLeftY = item->position().y();
-            bottomRightX = topLeftX + item->width();
-            bottomRightY = topLeftY + item->height();
-            ++itemCount;
-        }
         if (itemCount == 0) {
             minX = topLeftX;
             maxX = bottomRightX;
@@ -1138,9 +1105,11 @@ void QDeclarativeGeoMap::fitViewportToMapItemsRefine(bool refine)
         ++itemCount;
     }
 
-    if (itemCount == 0)
+    if (itemCount == 0) {
+        if (haveQuickItem)
+            fitViewportToMapItemsRefine(false);
         return;
-
+    }
     double bboxWidth = maxX - minX;
     double bboxHeight = maxY - minY;
     double bboxCenterX = minX + (bboxWidth / 2.0);
