@@ -1,40 +1,32 @@
 /****************************************************************************
  **
- ** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+ ** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
  ** Contact: http://www.qt-project.org/legal
  **
  ** This file is part of the QtLocation module of the Qt Toolkit.
  **
- ** $QT_BEGIN_LICENSE:LGPL$
+ ** $QT_BEGIN_LICENSE:LGPL21$
  ** Commercial License Usage
  ** Licensees holding valid commercial Qt licenses may use this file in
  ** accordance with the commercial license agreement provided with the
  ** Software or, alternatively, in accordance with the terms contained in
- ** a written agreement between you and Digia.  For licensing terms and
- ** conditions see http://qt.digia.com/licensing.  For further information
+ ** a written agreement between you and Digia. For licensing terms and
+ ** conditions see http://qt.digia.com/licensing. For further information
  ** use the contact form at http://qt.digia.com/contact-us.
  **
  ** GNU Lesser General Public License Usage
  ** Alternatively, this file may be used under the terms of the GNU Lesser
- ** General Public License version 2.1 as published by the Free Software
- ** Foundation and appearing in the file LICENSE.LGPL included in the
- ** packaging of this file.  Please review the following information to
- ** ensure the GNU Lesser General Public License version 2.1 requirements
- ** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+ ** General Public License version 2.1 or version 3 as published by the Free
+ ** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+ ** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+ ** following information to ensure the GNU Lesser General Public License
+ ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+ ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
  **
  ** In addition, as a special exception, Digia gives you certain additional
- ** rights.  These rights are described in the Digia Qt LGPL Exception
+ ** rights. These rights are described in the Digia Qt LGPL Exception
  ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
  **
- ** GNU General Public License Usage
- ** Alternatively, this file may be used under the terms of the GNU
- ** General Public License version 3.0 as published by the Free Software
- ** Foundation and appearing in the file LICENSE.GPL included in the
- ** packaging of this file.  Please review the following information to
- ** ensure the GNU General Public License version 3.0 requirements will be
- ** met: http://www.gnu.org/copyleft/gpl.html.
- **
- **
  ** $QT_END_LICENSE$
  **
  ****************************************************************************/
@@ -45,6 +37,7 @@
 #include "error_messages.h"
 #include "locationvaluetypehelper_p.h"
 
+#include <QtCore/QScopedValueRollback>
 #include <QtGui/private/qtriangulator_p.h>
 #include <QtQml/QQmlInfo>
 #include <QtQml/QQmlContext>
@@ -55,6 +48,8 @@
 #include <QPainterPath>
 #include <qnumeric.h>
 
+#include "qdoublevector2d_p.h"
+
 /* poly2tri triangulator includes */
 #include "../../3rdparty/poly2tri/common/shapes.h"
 #include "../../3rdparty/poly2tri/sweep/cdt.h"
@@ -96,7 +91,7 @@ QT_BEGIN_NAMESPACE
     \l border.width properties.
 
     \note Since MapPolygons are geographic items, dragging a MapPolygon
-    (through the use of \l MapMouseArea) causes its vertices to be
+    (through the use of \l MouseArea) causes its vertices to be
     recalculated in the geographic coordinate space. The edges retain the
     same geographic lengths (latitude and longitude differences between the
     vertices), but they remain straight. Apparent stretching of the item occurs
@@ -112,7 +107,7 @@ QT_BEGIN_NAMESPACE
     or removing points.
 
     Like the other map objects, MapPolygon is normally drawn without a smooth
-    appearance. Setting the \l {QtQuick2::Item::opacity}{opacity} property will force the object to
+    appearance. Setting the \l {QtQuick::Item::opacity}{opacity} property will force the object to
     be blended, which decreases performance considerably depending on the hardware in use.
 
     \section2 Example Usage
@@ -142,8 +137,8 @@ struct Vertex
     QVector2D position;
 };
 
-QGeoMapPolygonGeometry::QGeoMapPolygonGeometry(QObject *parent) :
-    QGeoMapItemGeometry(parent), assumeSimple_(false)
+QGeoMapPolygonGeometry::QGeoMapPolygonGeometry()
+:   assumeSimple_(false)
 {
 }
 
@@ -156,14 +151,14 @@ void QGeoMapPolygonGeometry::updateSourcePoints(const QGeoMap &map,
     if (!sourceDirty_)
         return;
 
-    qreal minX = -1.0;
+    double minX = -1.0;
 
     // build the actual path
-    QPointF origin;
-    QPointF lastPoint;
+    QDoubleVector2D origin;
+    QDoubleVector2D lastPoint;
     srcPath_ = QPainterPath();
 
-    qreal unwrapBelowX = 0;
+    double unwrapBelowX = 0;
     if (preserveGeometry_ )
         unwrapBelowX = map.coordinateToScreenPosition(geoLeftBound_, false).x();
 
@@ -173,7 +168,7 @@ void QGeoMapPolygonGeometry::updateSourcePoints(const QGeoMap &map,
         if (!coord.isValid())
             continue;
 
-        QPointF point = map.coordinateToScreenPosition(coord, false);
+        QDoubleVector2D point = map.coordinateToScreenPosition(coord, false);
 
         // We can get NaN if the map isn't set up correctly, or the projection
         // is faulty -- probably best thing to do is abort
@@ -188,14 +183,14 @@ void QGeoMapPolygonGeometry::updateSourcePoints(const QGeoMap &map,
             origin = point;
             minX = point.x();
             srcOrigin_ = coord;
-            srcPath_.moveTo(point - origin);
+            srcPath_.moveTo(point.toPointF() - origin.toPointF());
             lastPoint = point;
         } else {
             if (point.x() <= minX)
                 minX = point.x();
-            const QPointF diff = (point - lastPoint);
+            const QDoubleVector2D diff = (point - lastPoint);
             if (diff.x() * diff.x() + diff.y() * diff.y() >= 3.0) {
-                srcPath_.lineTo(point - origin);
+                srcPath_.lineTo(point.toPointF() - origin.toPointF());
                 lastPoint = point;
             }
         }
@@ -207,7 +202,7 @@ void QGeoMapPolygonGeometry::updateSourcePoints(const QGeoMap &map,
         srcPath_ = srcPath_.simplified();
 
     sourceBounds_ = srcPath_.boundingRect();
-    geoLeftBound_ = map.screenPositionToCoordinate(QPointF(minX, 0), false);
+    geoLeftBound_ = map.screenPositionToCoordinate(QDoubleVector2D(minX, 0), false);
 }
 
 /*!
@@ -223,12 +218,12 @@ void QGeoMapPolygonGeometry::updateScreenPoints(const QGeoMap &map)
         return;
     }
 
-    QPointF origin = map.coordinateToScreenPosition(srcOrigin_, false);
+    QDoubleVector2D origin = map.coordinateToScreenPosition(srcOrigin_, false);
 
     // Create the viewport rect in the same coordinate system
     // as the actual points
     QRectF viewport(0, 0, map.width(), map.height());
-    viewport.translate(-1 * origin);
+    viewport.translate(-1 * origin.toPointF());
 
     QPainterPath vpPath;
     vpPath.addRect(viewport);
@@ -294,7 +289,7 @@ void QGeoMapPolygonGeometry::updateScreenPoints(const QGeoMap &map)
                     p2t::Triangle *t = tris.at(i);
                     for (int j = 0; j < 3; ++j) {
                         p2t::Point *p = t->GetPoint(j);
-                        screenVertices_ << Point(p->x, p->y);
+                        screenVertices_ << QPointF(p->x, p->y);
                     }
                 }
                 delete cdt;
@@ -318,10 +313,9 @@ void QGeoMapPolygonGeometry::updateScreenPoints(const QGeoMap &map)
 
 }
 
-QDeclarativePolygonMapItem::QDeclarativePolygonMapItem(QQuickItem *parent) :
-    QDeclarativeGeoMapItemBase(parent),
-    color_(Qt::transparent),
-    dirtyMaterial_(true)
+QDeclarativePolygonMapItem::QDeclarativePolygonMapItem(QQuickItem *parent)
+:   QDeclarativeGeoMapItemBase(parent), color_(Qt::transparent), dirtyMaterial_(true),
+    updatingGeometry_(false)
 {
     setFlag(ItemHasContents, true);
     QObject::connect(&border_, SIGNAL(colorChanged(QColor)),
@@ -349,7 +343,7 @@ QDeclarativePolygonMapItem::~QDeclarativePolygonMapItem()
     \qmlproperty color MapPolygon::border.color
 
     This property is part of the border property group. The border property
-    group holds the width and color used to draw the border of the circle.
+    group holds the width and color used to draw the border of the polygon.
 
     The width is in pixels and is independent of the zoom level of the map.
 
@@ -467,12 +461,12 @@ void QDeclarativePolygonMapItem::removeCoordinate(const QGeoCoordinate &coordina
     int index = path_.lastIndexOf(coordinate);
 
     if (index == -1) {
-        qmlInfo(this) << QCoreApplication::translate(CONTEXT_NAME, COORD_NOT_BELONG_TO).arg("PolygonMapItem");
+        qmlInfo(this) << COORD_NOT_BELONG_TO << QStringLiteral("PolygonMapItem");
         return;
     }
 
     if (path_.count() < index + 1) {
-        qmlInfo(this) << QCoreApplication::translate(CONTEXT_NAME, COORD_NOT_BELONG_TO).arg("PolygonMapItem");
+        qmlInfo(this) << COORD_NOT_BELONG_TO << QStringLiteral("PolygonMapItem");
         return;
     }
     path_.removeAt(index);
@@ -538,26 +532,27 @@ void QDeclarativePolygonMapItem::updateMapItem()
     if (!map() || path_.count() == 0)
         return;
 
+    QScopedValueRollback<bool> rollback(updatingGeometry_);
+    updatingGeometry_ = true;
+
     geometry_.updateSourcePoints(*map(), path_);
     geometry_.updateScreenPoints(*map());
 
-    if (border_.color() != Qt::transparent && border_.width() > 0) {
-        QList<QGeoCoordinate> closedPath = path_;
-        closedPath << closedPath.first();
-        borderGeometry_.updateSourcePoints(*map(), closedPath);
+    QList<QGeoCoordinate> closedPath = path_;
+    closedPath << closedPath.first();
+    borderGeometry_.clear();
+    borderGeometry_.updateSourcePoints(*map(), closedPath);
+
+    if (border_.color() != Qt::transparent && border_.width() > 0)
         borderGeometry_.updateScreenPoints(*map(), border_.width());
 
-        QList<QGeoMapItemGeometry *> geoms;
-        geoms << &geometry_ << &borderGeometry_;
-        QRectF combined = QGeoMapItemGeometry::translateToCommonOrigin(geoms);
+    QList<QGeoMapItemGeometry *> geoms;
+    geoms << &geometry_ << &borderGeometry_;
+    QRectF combined = QGeoMapItemGeometry::translateToCommonOrigin(geoms);
+
+    setWidth(combined.width());
+    setHeight(combined.height());
 
-        setWidth(combined.width());
-        setHeight(combined.height());
-    } else {
-        borderGeometry_.clear();
-        setWidth(geometry_.sourceBoundingBox().width());
-        setHeight(geometry_.sourceBoundingBox().height());
-    }
     setPositionOnMap(path_.at(0), -1 * geometry_.sourceBoundingBox().topLeft());
     update();
 }
@@ -609,19 +604,14 @@ bool QDeclarativePolygonMapItem::contains(const QPointF &point) const
 /*!
     \internal
 */
-void QDeclarativePolygonMapItem::dragStarted()
+void QDeclarativePolygonMapItem::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
 {
-    geometry_.markFullScreenDirty();
-    borderGeometry_.markFullScreenDirty();
-    updateMapItem();
-}
+    if (updatingGeometry_ || newGeometry.topLeft() == oldGeometry.topLeft()) {
+        QDeclarativeGeoMapItemBase::geometryChanged(newGeometry, oldGeometry);
+        return;
+    }
 
-/*!
-    \internal
-*/
-void QDeclarativePolygonMapItem::dragEnded()
-{
-    QPointF newPoint = QPointF(x(),y()) + geometry_.firstPointOffset();
+    QDoubleVector2D newPoint = QDoubleVector2D(x(),y()) + QDoubleVector2D(geometry_.firstPointOffset());
     QGeoCoordinate newCoordinate = map()->screenPositionToCoordinate(newPoint, false);
     if (newCoordinate.isValid()) {
         double firstLongitude = path_.at(0).longitude();
@@ -660,6 +650,9 @@ void QDeclarativePolygonMapItem::dragEnded()
         updateMapItem();
         emit pathChanged();
     }
+
+    // Not calling QDeclarativeGeoMapItemBase::geometryChanged() as it will be called from a nested
+    // call to this function.
 }
 
 //////////////////////////////////////////////////////////////////////
