@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtLocation module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ** This file is part of the Nokia services plugin for the Maps and
@@ -126,13 +118,13 @@ void QPlaceSearchReplyImpl::replyFinished()
     if (resultsObject.contains(QStringLiteral("results")))
         resultsObject = resultsObject.value(QStringLiteral("results")).toObject();
 
-    QJsonArray items = resultsObject.value(QLatin1String("items")).toArray();
+    QJsonArray items = resultsObject.value(QStringLiteral("items")).toArray();
 
     QList<QPlaceSearchResult> results;
     for (int i = 0; i < items.count(); ++i) {
         QJsonObject item = items.at(i).toObject();
 
-        const QString type = item.value(QLatin1String("type")).toString();
+        const QString type = item.value(QStringLiteral("type")).toString();
         if (type == QStringLiteral("urn:nlp-types:place"))
             results.append(parsePlaceResult(item));
         else if (type == QStringLiteral("urn:nlp-types:search"))
@@ -164,22 +156,22 @@ QPlaceResult QPlaceSearchReplyImpl::parsePlaceResult(const QJsonObject &item) co
 {
     QPlaceResult result;
 
-    if (item.contains(QLatin1String("distance")))
-        result.setDistance(item.value(QLatin1String("distance")).toDouble());
+    if (item.contains(QStringLiteral("distance")))
+        result.setDistance(item.value(QStringLiteral("distance")).toDouble());
 
     QPlace place;
 
     QGeoLocation location;
 
-    location.setCoordinate(parseCoordinate(item.value(QLatin1String("position")).toArray()));
+    location.setCoordinate(parseCoordinate(item.value(QStringLiteral("position")).toArray()));
 
-    const QString vicinity = item.value(QLatin1String("vicinity")).toString();
+    const QString vicinity = item.value(QStringLiteral("vicinity")).toString();
     QGeoAddress address;
     address.setText(vicinity);
     location.setAddress(address);
 
-    if (item.contains(QLatin1String("bbox"))) {
-        QJsonArray bbox = item.value(QLatin1String("bbox")).toArray();
+    if (item.contains(QStringLiteral("bbox"))) {
+        QJsonArray bbox = item.value(QStringLiteral("bbox")).toArray();
         QGeoRectangle box(QGeoCoordinate(bbox.at(3).toDouble(), bbox.at(0).toDouble()),
                             QGeoCoordinate(bbox.at(1).toDouble(), bbox.at(2).toDouble()));
         location.setBoundingBox(box);
@@ -188,32 +180,32 @@ QPlaceResult QPlaceSearchReplyImpl::parsePlaceResult(const QJsonObject &item) co
     place.setLocation(location);
 
     QPlaceRatings ratings;
-    ratings.setAverage(item.value(QLatin1String("averageRating")).toDouble());
+    ratings.setAverage(item.value(QStringLiteral("averageRating")).toDouble());
     ratings.setMaximum(5.0);
     place.setRatings(ratings);
 
-    const QString title = item.value(QLatin1String("title")).toString();
+    const QString title = item.value(QStringLiteral("title")).toString();
     place.setName(title);
     result.setTitle(title);
 
-    QPlaceIcon icon = m_engine->icon(item.value(QLatin1String("icon")).toString());
+    QPlaceIcon icon = m_engine->icon(item.value(QStringLiteral("icon")).toString());
     place.setIcon(icon);
     result.setIcon(icon);
 
-    place.setCategory(parseCategory(item.value(QLatin1String("category")).toObject(),
+    place.setCategory(parseCategory(item.value(QStringLiteral("category")).toObject(),
                                     m_engine));
 
-    //QJsonArray having = item.value(QLatin1String("having")).toArray();
+    //QJsonArray having = item.value(QStringLiteral("having")).toArray();
 
-    result.setSponsored(item.value(QLatin1String("sponsored")).toBool());
+    result.setSponsored(item.value(QStringLiteral("sponsored")).toBool());
 
-    QUrl href = item.value(QLatin1String("href")).toString();
-    //QUrl type = item.value(QLatin1String("type")).toString();
+    QUrl href = item.value(QStringLiteral("href")).toString();
+    //QUrl type = item.value(QStringLiteral("type")).toString();
 
     place.setPlaceId(href.path().mid(18, 41));
 
     QPlaceAttribute provider;
-    provider.setText(QLatin1String("nokia"));
+    provider.setText(QStringLiteral("nokia"));
     place.setExtendedAttribute(QPlaceAttribute::Provider, provider);
     place.setVisibility(QLocation::PublicVisibility);
 
@@ -226,7 +218,7 @@ QPlaceProposedSearchResult QPlaceSearchReplyImpl::parseSearchResult(const QJsonO
 {
     QPlaceProposedSearchResult result;
 
-    result.setTitle(item.value(QLatin1String("title")).toString());
+    result.setTitle(item.value(QStringLiteral("title")).toString());
 
     QPlaceIcon icon = m_engine->icon(item.value(QStringLiteral("icon")).toString());
     result.setIcon(icon);
