@@ -5,36 +5,28 @@
 **
 ** This file is part of the QtLocation module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -339,6 +331,7 @@ void QGeoRouteReplyOsm::networkReplyFinished()
     if (m_reply->error() != QNetworkReply::NoError) {
         setError(QGeoRouteReply::CommunicationError, m_reply->errorString());
         m_reply->deleteLater();
+        m_reply = 0;
         return;
     }
 
@@ -348,8 +341,18 @@ void QGeoRouteReplyOsm::networkReplyFinished()
         QJsonObject object = document.object();
 
         //double version = object.value(QStringLiteral("version")).toDouble();
-        //int status = object.value(QStringLiteral("status")).toDouble();
-        //QString statusMessage = object.value(QStringLiteral("status_message")).toString();
+        int status = object.value(QStringLiteral("status")).toDouble();
+        QString statusMessage = object.value(QStringLiteral("status_message")).toString();
+
+        // status code is 0 in case of success
+        // status code is 207 if no route was found
+        // an error occurred when trying to find a route
+        if (0 != status) {
+            setError(QGeoRouteReply::UnknownError, statusMessage);
+            m_reply->deleteLater();
+            m_reply = 0;
+            return;
+        }
 
         QJsonObject routeSummary = object.value(QStringLiteral("route_summary")).toObject();
 
@@ -384,10 +387,11 @@ void QGeoRouteReplyOsm::networkReplyFinished()
 
         setFinished(true);
     } else {
-        setError(QGeoRouteReply::ParseError, QLatin1String("Couldn't parse json."));
+        setError(QGeoRouteReply::ParseError, QStringLiteral("Couldn't parse json."));
     }
 
     m_reply->deleteLater();
+    m_reply = 0;
 }
 
 void QGeoRouteReplyOsm::networkReplyError(QNetworkReply::NetworkError error)
