@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtPositioning module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -510,6 +502,22 @@ QString QGeoCoordinate::toString(CoordinateFormat format) const
         case DegreesMinutesWithHemisphere: {
             double latMin = (absLat - int(absLat)) * 60;
             double lngMin = (absLng - int(absLng)) * 60;
+
+            if (qRound(latMin) >= 60) {
+                absLat++;
+                latMin = qAbs(latMin - 60.0f);
+                //avoid invalid latitude due to latMin rounding below
+                if (qRound(absLat) >= 90)
+                    latMin = 0.0f;
+            }
+            if (qRound(lngMin) >= 60) {
+                absLng++;
+                lngMin = qAbs(lngMin - 60.0f);
+                // avoid invalid longitude due to lngMin rounding below
+                if (qRound(absLng) >= 180)
+                    lngMin = 0.0f;
+            }
+
             latStr = QString::fromLatin1("%1%2 %3'")
                      .arg(QString::number(int(absLat)))
                      .arg(symbol)
@@ -527,6 +535,31 @@ QString QGeoCoordinate::toString(CoordinateFormat format) const
             double latSec = (latMin - int(latMin)) * 60;
             double lngSec = (lngMin - int(lngMin)) * 60;
 
+            // overflow to full minutes
+            if (qRound(latSec) >= 60) {
+                latMin++;
+                latSec = qAbs(latSec - 60.0f);
+                // overflow to full degrees
+                if (qRound(latMin) >= 60) {
+                    absLat++;
+                    latMin = qAbs(latMin - 60.0f);
+                    // avoid invalid latitude due to latSec rounding below
+                    if (qRound(absLat) >= 90)
+                        latSec = 0.0f;
+                }
+            }
+            if (qRound(lngSec) >= 60) {
+                lngMin++;
+                lngSec = qAbs(lngSec - 60.0f);
+                if (qRound(lngMin) >= 60) {
+                    absLng++;
+                    lngMin = qAbs(lngMin - 60.0f);
+                    // avoid invalid longitude due to lngSec rounding below
+                    if (qRound(absLng) >= 180)
+                        lngSec = 0.0f;
+                }
+            }
+
             latStr = QString::fromLatin1("%1%2 %3' %4\"")
                      .arg(QString::number(int(absLat)))
                      .arg(symbol)
@@ -547,9 +580,9 @@ QString QGeoCoordinate::toString(CoordinateFormat format) const
         case DegreesMinutes:
         case DegreesMinutesSeconds: {
             if (d->lat < 0)
-                latStr.insert(0, QLatin1String("-"));
+                latStr.insert(0, QStringLiteral("-"));
             if (d->lng < 0)
-                longStr.insert(0, QLatin1String("-"));
+                longStr.insert(0, QStringLiteral("-"));
             break;
         }
         case DegreesWithHemisphere:
