@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the test suite of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -295,7 +287,7 @@ public:
                                 if (ro.contains(QStringLiteral("dateTime")))
                                     review.setDateTime(QDateTime::fromString(
                                                            ro.value(QStringLiteral("dateTime")).toString(),
-                                                           QLatin1String("hh:mm dd-MM-yyyy")));
+                                                           QStringLiteral("hh:mm dd-MM-yyyy")));
                                 if (ro.contains(QStringLiteral("reviewId")))
                                     review.setReviewId(ro.value("reviewId").toString());
 
@@ -651,12 +643,12 @@ public:
         QList<QPair<int, QUrl> > candidates;
 
         QMap<QString, int> sizeDictionary;
-        sizeDictionary.insert(QLatin1String("s"), 20);
-        sizeDictionary.insert(QLatin1String("m"), 30);
-        sizeDictionary.insert(QLatin1String("l"), 50);
+        sizeDictionary.insert(QStringLiteral("s"), 20);
+        sizeDictionary.insert(QStringLiteral("m"), 30);
+        sizeDictionary.insert(QStringLiteral("l"), 50);
 
         QStringList sizeKeys;
-        sizeKeys << QLatin1String("s") << QLatin1String("m") << QLatin1String("l");
+        sizeKeys << QStringLiteral("s") << QStringLiteral("m") << QStringLiteral("l");
 
         foreach (const QString &sizeKey, sizeKeys)
         {
