@@ -1,40 +1,32 @@
 /*********************f*******************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the test suite of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -250,9 +242,9 @@ void TestQGeoSatelliteInfoSource::startUpdates_testIntervals()
 {
     CHECK_SOURCE_VALID;
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy timeout(m_source, SIGNAL(requestTimeout()));
     m_source->setUpdateInterval(7000);
     int interval = m_source->updateInterval();
@@ -279,9 +271,9 @@ void TestQGeoSatelliteInfoSource::startUpdates_testIntervalChangesWhileRunning()
 
     CHECK_SOURCE_VALID;
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy timeout(m_source, SIGNAL(requestTimeout()));
     m_source->setUpdateInterval(0);
     m_source->startUpdates();
@@ -334,9 +326,9 @@ void TestQGeoSatelliteInfoSource::startUpdates_testDefaultInterval()
 {
     CHECK_SOURCE_VALID;
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy timeout(m_source, SIGNAL(requestTimeout()));
     m_source->startUpdates();
     for (int i = 0; i < 3; i++) {
@@ -351,9 +343,9 @@ void TestQGeoSatelliteInfoSource::startUpdates_testZeroInterval()
 {
     CHECK_SOURCE_VALID;
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy timeout(m_source, SIGNAL(requestTimeout()));
 
     m_source->setUpdateInterval(0);
@@ -370,9 +362,9 @@ void TestQGeoSatelliteInfoSource::startUpdates_moreThanOnce()
 {
     CHECK_SOURCE_VALID;
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     m_source->setUpdateInterval(0);
     m_source->startUpdates();
 
@@ -391,9 +383,9 @@ void TestQGeoSatelliteInfoSource::stopUpdates()
     CHECK_SOURCE_VALID;
 
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     m_source->setUpdateInterval(10000);
     m_source->startUpdates();
 
@@ -422,7 +414,7 @@ void TestQGeoSatelliteInfoSource::requestUpdate()
     QFETCH(int, timeout);
     QSignalSpy spy(m_source, SIGNAL(requestTimeout()));
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     m_source->requestUpdate(timeout);
     // Geoclue may deliver update instantly if there is a satellite fix
     QTRY_VERIFY_WITH_TIMEOUT(!spy.isEmpty() || !spyView.isEmpty(), 10);
@@ -440,9 +432,9 @@ void TestQGeoSatelliteInfoSource::requestUpdate_validTimeout()
     CHECK_SOURCE_VALID;
 
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyTimeout(m_source, SIGNAL(requestTimeout()));
 
     m_source->requestUpdate(7000);
@@ -456,9 +448,9 @@ void TestQGeoSatelliteInfoSource::requestUpdate_defaultTimeout()
     CHECK_SOURCE_VALID;
 
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyTimeout(m_source, SIGNAL(requestTimeout()));
 
     m_source->requestUpdate(0);
@@ -483,9 +475,9 @@ void TestQGeoSatelliteInfoSource::requestUpdate_repeatedCalls()
     CHECK_SOURCE_VALID;
 
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
 
     m_source->requestUpdate(7000);
 
@@ -503,9 +495,9 @@ void TestQGeoSatelliteInfoSource::requestUpdate_overlappingCalls()
     CHECK_SOURCE_VALID;
 
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
 
     m_source->requestUpdate(7000);
     m_source->requestUpdate(7000);
@@ -518,9 +510,9 @@ void TestQGeoSatelliteInfoSource::requestUpdate_overlappingCallsWithTimeout()
     CHECK_SOURCE_VALID;
 
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyTimeout(m_source,
                       SIGNAL(requestTimeout()));
 
@@ -537,9 +529,9 @@ void TestQGeoSatelliteInfoSource::requestUpdateAfterStartUpdates_ZeroInterval()
     CHECK_SOURCE_VALID;
 
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyTimeout(m_source, SIGNAL(requestTimeout()));
 
     m_source->setUpdateInterval(0);
@@ -567,9 +559,9 @@ void TestQGeoSatelliteInfoSource::requestUpdateAfterStartUpdates_SmallInterval()
     CHECK_SOURCE_VALID;
 
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyTimeout(m_source, SIGNAL(requestTimeout()));
     m_source->setUpdateInterval(10000);
     m_source->requestUpdate(7000);
@@ -591,9 +583,9 @@ void TestQGeoSatelliteInfoSource::requestUpdateBeforeStartUpdates_ZeroInterval()
 {
     CHECK_SOURCE_VALID;
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy timeout(m_source, SIGNAL(requestTimeout()));
 
     m_source->requestUpdate(7000);
@@ -616,9 +608,9 @@ void TestQGeoSatelliteInfoSource::requestUpdateBeforeStartUpdates_SmallInterval(
 {
     CHECK_SOURCE_VALID;
     QSignalSpy spyView(m_source,
-                       SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)));
+                       SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy spyUse(m_source,
-                      SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)));
+                      SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)));
     QSignalSpy timeout(m_source, SIGNAL(requestTimeout()));
 
     m_source->requestUpdate(7000);
@@ -656,11 +648,11 @@ void TestQGeoSatelliteInfoSource::removeSlotForSatellitesInUseUpdated()
 {
     CHECK_SOURCE_VALID;
 
-    bool i = connect(m_source, SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)), this, SLOT(test_slot1()));
+    bool i = connect(m_source, SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)), this, SLOT(test_slot1()));
     QVERIFY(i == true);
-    i = connect(m_source, SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)), this, SLOT(test_slot2()));
+    i = connect(m_source, SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)), this, SLOT(test_slot2()));
     QVERIFY(i == true);
-    i = disconnect(m_source, SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo> &)), this, SLOT(test_slot1()));
+    i = disconnect(m_source, SIGNAL(satellitesInUseUpdated(QList<QGeoSatelliteInfo>)), this, SLOT(test_slot1()));
     QVERIFY(i == true);
 
     m_source->requestUpdate(7000);
@@ -672,11 +664,11 @@ void TestQGeoSatelliteInfoSource::removeSlotForSatellitesInViewUpdated()
 {
     CHECK_SOURCE_VALID;
 
-    bool i = connect(m_source, SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)), this, SLOT(test_slot1()));
+    bool i = connect(m_source, SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)), this, SLOT(test_slot1()));
     QVERIFY(i == true);
-    i = connect(m_source, SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)), this, SLOT(test_slot2()));
+    i = connect(m_source, SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)), this, SLOT(test_slot2()));
     QVERIFY(i == true);
-    i = disconnect(m_source, SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo> &)), this, SLOT(test_slot1()));
+    i = disconnect(m_source, SIGNAL(satellitesInViewUpdated(QList<QGeoSatelliteInfo>)), this, SLOT(test_slot1()));
     QVERIFY(i == true);
 
     m_source->requestUpdate(7000);
